@@ -1,4 +1,4 @@
-__version__ = '1.0.1'
+__version__ = '1.0.4'
 import os, time
 
 def clear():
@@ -47,4 +47,7 @@ bg_br_magenta = "\033[0;105m"
 bg_br_cyan = "\033[0;106m"
 bg_br_white = "\033[0;107m"
 
-reset = '\033[0m'
\ No newline at end of file
+
+reset = '\033[0m'
+def print_error(msg, color = red):
+  print(f"{color}{msg}{reset}")
\ No newline at end of file
